@@ -91,7 +91,7 @@ apply_cells_column_labels <- function(gt,loc){
 #' @importFrom gt tab_footnote md opt_footnote_marks
 apply_cells_column_spanners <- function(gt,loc){
   # check row is empty - therefore a column footnote
-  if(is.null(loc$row) && loc$spanning ==TRUE){
+  if(!is.null(loc) && is.null(loc$row) && loc$spanning ==TRUE){
 
     gt<- gt %>%
       tab_footnote(
@@ -119,12 +119,22 @@ apply_cells_column_spanners <- function(gt,loc){
 #' @importFrom rlang quo_get_expr
 apply_cells_stub <-  function(gt,tfrmt,loc){
   if(length(loc$col)>0){
-  if(all(loc$col == as_label(tfrmt$label))){
+
+  in_stub <- (
+    #column row grp label (all stubs)
+    (!is.null(tfrmt$row_grp_plan) &&
+                tfrmt$row_grp_plan$label_loc$location=="column") &&
+    all(loc$col %in% map_chr(c(tfrmt$group, tfrmt$label), as_label)) ||
+      # in the label
+      (all(loc$col==as_label(tfrmt$label)))
+    )
+
+  if(in_stub){
 
     gt<- gt %>%
       tab_footnote(
         footnote = loc$note,
-        locations = cells_stub(rows = loc$row)
+        locations = cells_stub(rows = loc$row, columns = loc$col)
       )
 
 
