@@ -249,7 +249,12 @@ apply_frmt.frmt_combine <- function(frmt_def, .data, value, mock = FALSE, param,
         TRUE ~ str_glue(!!frmt_def$expression) %>% as.character()
       )
     ) %>%
-    select(-all_of(fmt_param_vals_uq), -".is_all_missing")
+    select(
+      -tidyselect::all_of(
+        fmt_param_vals_uq
+      ),
+      -".is_all_missing"
+    )
 
   ## if not mock remove
   if(!mock){
@@ -341,4 +346,3 @@ apply_frmt.frmt_when <- function(frmt_def, .data, value, mock = FALSE, ...){
   out
 
 }
-
