@@ -14,7 +14,14 @@ apply_page_plan <- function(.data, page_plan, group, label, row_grp_plan_label_l
 
   # first apply page structures
   if (!is_empty(page_plan$struct_list)){
-    .data <- apply_page_struct(.data, page_plan$struct_list, group, label, page_plan$note_loc)
+    .data <- apply_page_struct(
+      .data,
+      page_struct_list = page_plan$struct_list,
+      group = group,
+      label = label,
+      note_loc = page_plan$note_loc,
+      transform = page_plan$transform
+    )
   }
 
   # then apply max rows splits
@@ -43,7 +50,6 @@ apply_page_plan <- function(.data, page_plan, group, label, row_grp_plan_label_l
 #'
 #' @noRd
 #' @importFrom dplyr  slice bind_rows filter pull
-#' @importFrom tidyselect contains
 #' @importFrom tibble tibble
 #' @importFrom forcats fct_inorder
 apply_page_max_rows <- function(.data, max_rows, group, label, row_grp_plan_label_loc){
@@ -56,14 +62,13 @@ apply_page_max_rows <- function(.data, max_rows, group, label, row_grp_plan_labe
   #
   #      - "gtdefault": +1
   #      - "spanning" / "indented" : # of grouping vars
-  #      - "column": # of grouping vars - 1
-  #      - "noprint": +0
+  #      - "noprint", "column": +0
   n_grp_vars <- length(group)
   n_grp_rows <- switch(row_grp_plan_label_loc,
                        gtdefault = 1,
                        spanning = n_grp_vars,
                        indented = n_grp_vars,
-                       column = n_grp_vars-1,
+                       column = 0,
                        noprint = 0)
 
   if (!n_grp_rows<max_rows){
@@ -99,9 +104,17 @@ apply_page_max_rows <- function(.data, max_rows, group, label, row_grp_plan_labe
     }
 
     # if this row is added, how many rows will be in table
-    cur_dat_new <- bind_rows(cur_dat, next_dat) %>%
-      combine_group_cols_mod(group, label, row_grp_plan_label_loc)
+    # cur_dat_new <- bind_rows(cur_dat, next_dat) %>%
+    #   combine_group_cols_mod(group, label, row_grp_plan_label_loc)
 
+    if(length(group)==0 || is_empty(label) || row_grp_plan_label_loc %in% c("gtdefault", "noprint", "column")){
+      cur_dat_new <- bind_rows(cur_dat, next_dat)
+    } else{
+      #  combine any grouping columns that need combining into label
+      cur_dat_new <- bind_rows(cur_dat, next_dat) %>%
+        combine_group_cols_mod(group, label, row_grp_plan_label_loc)
+
+    }
 
     # if the table is within our limit, keep it
     if (nrow(cur_dat_new) <= max_rows){
@@ -144,13 +157,20 @@ apply_page_max_rows <- function(.data, max_rows, group, label, row_grp_plan_labe
 #' @param group symbolic list of grouping
 #' @param label symbolic label column
 #' @param note_loc location of page note
+#' @param transform optional, a function or formula to transform the page label.
 #'
 #' @noRd
 #' @importFrom purrr map map2 map_dbl
 #' @importFrom dplyr tibble row_number mutate group_by left_join select filter summarise  lag last
 #' @importFrom tidyr  pivot_longer
-apply_page_struct <- function(.data, page_struct_list, group, label, note_loc){
-
+apply_page_struct <- function(
+  .data,
+  page_struct_list,
+  group,
+  label,
+  note_loc,
+  transform
+) {
   .data <- .data %>%
     mutate(TEMP_row = row_number())
 
@@ -174,8 +194,13 @@ apply_page_struct <- function(.data, page_struct_list, group, label, note_loc){
     grping <- expr_to_grouping(page_struct_list[[struct_defaults_idx]], group, label)
 
     dat_split_1 <- .data %>%
-      nest(`..tfrmt_data` = everything(), .by = (all_of(grping))) %>%
-      mutate(`..tfrmt_split_num` = row_number())
+      nest(
+        `..tfrmt_data` = tidyselect::everything(),
+        .by = tidyselect::all_of(grping)
+      ) %>%
+      mutate(
+        `..tfrmt_split_num` = row_number()
+      )
 
   } else {
     # no default - just nest to get in same structure for next step
@@ -218,7 +243,7 @@ apply_page_struct <- function(.data, page_struct_list, group, label, note_loc){
       group_by(.data$`..tfrmt_split_num`) %>%
       filter(!is.na(.data$grouping_val)) %>%
       unique() %>%
-      summarise(`..tfrmt_page_note` = paste0(.data$grouping_col, ": ", .data$grouping_val) %>% paste0(collapse = ",\n"))
+      summarise(`..tfrmt_page_note` = paste0(.data$grouping_col, ": ", .data$grouping_val) %>% paste0(collapse = ", "))
 
     page_grp_vars <- setdiff(names(dat_split_2), c("..tfrmt_data", "..tfrmt_split_num"))
 
@@ -238,10 +263,20 @@ apply_page_struct <- function(.data, page_struct_list, group, label, note_loc){
   # add pg_note to individual tbls as applicable
   if ("..tfrmt_page_note" %in% names(dat_split_2)){
     pg_note <- dat_split_2$`..tfrmt_page_note`
-    dat_out <-  dat_out %>%
-      map2(., pg_note, ~ structure(.x,
-                                   .page_note = .y))
 
+    if (!is.null(transform)) {
+      transform <- rlang::as_function(transform)
+      pg_note <- transform(pg_note)
+    }
+
+    dat_out <- purrr::map2(
+      dat_out,
+      pg_note,
+      ~ structure(
+        .x,
+        .page_note = .y
+      )
+    )
   }
 
   structure(
@@ -258,7 +293,6 @@ apply_page_struct <- function(.data, page_struct_list, group, label, note_loc){
 #' @importFrom dplyr mutate select across group_by group_split distinct last bind_rows
 #' @importFrom tibble tibble
 #' @importFrom stringr str_trim
-#' @importFrom tidyselect any_of
 combine_group_cols_mod <- function(.data, group, label, element_row_grp_loc = NULL){
 
   top_grouping <- group #used for splitting in case of spanning label
@@ -270,8 +304,7 @@ combine_group_cols_mod <- function(.data, group, label, element_row_grp_loc = NU
            ..tfrmt_row_grp_lbl = FALSE)%>%
     mutate(`..tfrmt_summary_row` = str_trim(!!label, side = "left") == str_trim(!!last(group), side = "left"))
 
-
-  if(element_row_grp_loc %in% c("spanning", "column") & length(group) > 0){
+  if(element_row_grp_loc %in% c("spanning") & length(group) > 0){
     group = group[-1]
   }
 
@@ -307,7 +340,11 @@ combine_group_cols_mod <- function(.data, group, label, element_row_grp_loc = NU
   }
 
   .data %>%
-    select(-any_of("..tfrmt_summary_row_cur"))
+    select(
+      -tidyselect::any_of(
+        "..tfrmt_summary_row_cur"
+      )
+    )
 }
 
 #' add any related summary rows from previous tbl to next tbl
@@ -315,7 +352,6 @@ combine_group_cols_mod <- function(.data, group, label, element_row_grp_loc = NU
 #' @importFrom dplyr mutate slice pull filter across select bind_rows
 #' @importFrom purrr map_chr map map2_lgl
 #' @importFrom tidyr pivot_longer
-#' @importFrom tidyselect all_of
 add_summary_rows <- function(next_dat, prev_summ, group, label){
 
   #get grouping values from the summary row
@@ -328,8 +364,16 @@ add_summary_rows <- function(next_dat, prev_summ, group, label){
     mutate(`..tfrmt_summ_grp_num` = which(.data$`..tfrmt_summ_grp_num`==map_chr(group, as_label))) %>%
     pull(.data$`..tfrmt_summ_grp_num`)
 
-  prev_summ_top_grp_vars <- map(seq_len(nrow(prev_summ)),
-                                ~prev_summ[.x,] %>% select(c(!!!group)) %>% select(1:all_of(prev_summ_top_grp[.x])))
+  prev_summ_top_grp_vars <- map(
+    seq_len(nrow(prev_summ)),
+    ~prev_summ[.x,] %>%
+      select(c(!!!group)) %>%
+      select(
+        1:tidyselect::all_of(
+          prev_summ_top_grp[.x]
+        )
+      )
+  )
 
   # get the grouping values from the next row
   next_summ_top_grp_vars <- map(prev_summ_top_grp_vars,
@@ -348,4 +392,3 @@ add_summary_rows <- function(next_dat, prev_summ, group, label){
   }
   next_dat
 }
-
