@@ -21,7 +21,7 @@
 #'  label = label ,
 #'  column = time,
 #'  param = param,
-#'  value = value) %>%
+#'  value = value) |>
 #'   print_to_ggplot(risk)
 #'
 #'table
@@ -189,11 +189,14 @@ apply_grp_ggplot<-function(.data,tfrmt){
     element<-element_row_grp_loc(location="indented", indent = "    ")
 
     combine_group_cols(.data,tfrmt$group,tfrmt$label,element) %>%
-      select(-all_of(group_name))
+      select(
+        -tidyselect::all_of(
+          group_name
+        )
+      )
 
 
   }else{
     .data
   }
 }
-
