@@ -33,7 +33,7 @@
 #'
 #'```r
 #'   # Create mock data
-#'   df <- crossing(label = c("label 1", "label 2",
+#'   df <- tidyr::crossing(label = c("label 1", "label 2",
 #'   "label 3"), column = c("placebo", "trt1", "trt2"), param = c("count",
 #'   "percent"))
 #'
@@ -46,7 +46,6 @@
 #'
 #'
 #' @importFrom gt gt tab_header tab_style cell_text cells_body px
-#' @importFrom tidyselect everything eval_select
 #' @importFrom rlang quo_is_missing sym quo is_empty
 #' @importFrom dplyr vars
 #' @importFrom purrr quietly safely
@@ -81,7 +80,7 @@ print_mock_gt <- function(tfrmt,
     .data <- make_mock_data(tfrmt, .default, n_cols)
   }else{
     ## check that if value column exists in data, remove it for mocking
-    select_try <- safely(quietly(eval_select))(tfrmt$value, data = .data)
+    select_try <- safely(quietly(tidyselect::eval_select))(tfrmt$value, data = .data)
     if(!is.null(select_try$result)){
       message(" Removing `",as_label(tfrmt$value),"` from input data for mocking.")
       .data <- .data[,-select_try$result$result]
@@ -123,10 +122,10 @@ print_mock_gt <- function(tfrmt,
 #'   ))
 #'
 #' # Create data
-#' df <- crossing(label = c("label 1", "label 2"),
+#' df <- tidyr::crossing(label = c("label 1", "label 2"),
 #'                column = c("placebo", "trt1"),
-#'                param = c("count", "percent")) %>%
-#'       mutate(value=c(24,19,2400/48,1900/38,5,1,500/48,100/38))
+#'                param = c("count", "percent")) |>
+#'       dplyr::mutate(value=c(24,19,2400/48,1900/38,5,1,500/48,100/38))
 #'
 #' print_to_gt(tfrmt_spec,df)
 #'
@@ -136,7 +135,6 @@ print_mock_gt <- function(tfrmt,
 #' }}
 #'
 #' @importFrom gt gt tab_header tab_style cell_text cells_body tab_options
-#' @importFrom tidyselect everything
 print_to_gt <- function(tfrmt, .data, .unicode_ws = TRUE){
   if(!is_tfrmt(tfrmt)){
     stop("Requires a tfrmt object")
@@ -192,21 +190,25 @@ cleaned_data_to_gt.list <- function(.data, tfrmt, .unicode_ws){
 #'   cells_body cells_column_labels md cols_hide sub_missing tab_stubhead
 cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
 
+  existing_grp <- tfrmt$group %>%
+    keep(function(x){
+      as_label(x) %in% names(.data)
+    })
+  rowname_col <- NULL
 
-  if((is.null(tfrmt$row_grp_plan) ||(!inherits(.data, "grouped_df"))) && length(tfrmt$group) > 0){
-    existing_grp <- tfrmt$group %>%
-      keep(function(x){
-        as_label(x) %in% names(.data)
-      })
-    .data <- .data %>%
-      group_by(!!!existing_grp)
+  if (length(existing_grp)>0){
+    if (!is.null(tfrmt$row_grp_plan) && !tfrmt$row_grp_plan$label_loc$location=="column") {
+
+      .data <- .data %>%
+        group_by(!!!existing_grp)
+
+    } else {
+
+      # drop groups into row names
+      rowname_col <- existing_grp
+    }
   }
 
-  if (!is.null(tfrmt$col_style_plan)){
-    align <- "left"
-  } else {
-    align <- NULL
-  }
   if (!"..tfrmt_row_grp_lbl" %in% names(.data)) {
     # keep attribute for footnotes
     attr_footnote <- attr(.data,".footnote_locs")
@@ -216,13 +218,15 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
     attr(.data,".stub_header") <- attr_stub_header
   }
 
-  rowname_col <- NULL
-
   if (!rlang::quo_is_missing(tfrmt$label) &&
         rlang::as_label(tfrmt$label) %in% names(.data)) {
-    rowname_col <- rlang::as_label(tfrmt$label)
+
+    rowname_col <- c(rowname_col, tfrmt$label)
   }
 
+  # convert to character if not null
+  rowname_col <- if (!is.null(rowname_col)) map_chr(rowname_col, rlang::as_label)
+
   gt_out <- .data %>%
     gt(
       rowname_col = rowname_col
@@ -232,11 +236,7 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
       missing_text = ""
     ) %>%
     cols_hide(columns = "..tfrmt_row_grp_lbl") %>%
-    format_gt_column_labels(.data) %>%
-    tab_style(
-      style = cell_text(whitespace = "pre-wrap", align = align),
-      locations = cells_body(columns = everything())
-    )
+    format_gt_column_labels(.data)
 
   # group label in its own column
   if(!is.null(tfrmt$row_grp_plan) && tfrmt$row_grp_plan$label_loc$location == "column"){
@@ -255,7 +255,7 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
       style = list(
         cell_text(whitespace = "pre-wrap", align = "left")
       ),
-      locations = list(cells_stub(), cells_row_groups())
+      locations = list(cells_stub(columns = rowname_col), cells_row_groups())
     ) %>%
     tab_options(
       table.font.size = 14,
@@ -280,7 +280,11 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
 
     tab_style(
       style = cell_text(whitespace = "pre-wrap", align = "center"),
-      locations = list(cells_column_spanners(),cells_column_labels())
+      locations = list(cells_column_spanners(),
+                       cells_column_labels(),
+                       cells_body(
+                         columns = tidyselect::everything()
+                       ))
     ) %>%
 
     tab_style(
@@ -290,10 +294,12 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
       ),
       locations= list(
         cells_body(
-          columns = everything(),
-          rows = everything()
+          columns = tidyselect::everything(),
+          rows = tidyselect::everything()
         ),
-        cells_stub(), cells_row_groups())
+        cells_stub(),
+        cells_row_groups()
+      )
     )  %>%
 
     tab_style(
@@ -321,6 +327,14 @@ cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
                        cells_column_labels(), cells_column_spanners())
     )
 
+  # remove vertical line
+  if (utils::packageVersion("gt") >= "1.3.0"){
+    gt_out_final <- gt_out_final %>%
+      tab_options(
+        stub.separate = FALSE
+      )
+  }
+
   # add page note if applicable
   if (!is.null(attr(.data, ".page_note")) &&
       !is.null(tfrmt$page_plan) &&
@@ -411,11 +425,16 @@ format_gt_column_labels <- function(gt_table, .data){
       mutate(set = map(.data$set, ~pull(.,.data$cols))) %>%
       filter(.data$value != "NA")
 
-    for(i in 1:nrow(spans_to_apply)){
+    for(i in 1:nrow(spans_to_apply)) {
 
       # convert column spanning labels to markdown format
       gt_table <- gt_table %>%
-        tab_spanner(md(spans_to_apply$value[i]), columns = all_of(spans_to_apply$set[[i]]))
+        tab_spanner(
+          md(spans_to_apply$value[i]),
+          columns = tidyselect::all_of(
+            spans_to_apply$set[[i]]
+          )
+        )
     }
 
     # ensure all columns are represented
@@ -468,7 +487,7 @@ convert_ws_unicode <- function(gt_table){
     text_transform(
       locations = locations,
       fn = function(x) {
-
+        # leading and trailing whitespace is nonbreaking unicode whitespace to preserve alignment
         x_trimmed <- str_trim(x)
         space_left <- str_match(x, "^\\s*") %>% nchar()
         space_right <- str_match(x, "\\s*$") %>% nchar()
@@ -476,9 +495,34 @@ convert_ws_unicode <- function(gt_table){
 
         str_c(
           str_dup("\U00A0", space_left),
-          x_trimmed,
+          # 2 or more spaces are split into a combination of unicode whitespaces and
+          # regular spaces for latex collapsing
+          str_replace_all(x_trimmed, pattern = "\\s{2,}", break_duplicate_whitespace),
           str_dup("\U00A0", space_right)
         )
+
+
       }
     )
 }
+
+# split duplicate space characters with unicode whitespace ones
+#' @param x whitespace vector of strings of length >1
+#' @importFrom stringr str_sub
+#' @noRd
+break_duplicate_whitespace <- function(x){
+
+  for(i in 1:length(x)){
+    n_spaces <- nchar(x[i])
+    if(n_spaces > 1 && !is.na(x[i])){
+      #want to swap every even indice for a unicode character
+      even_chars <- seq(from = 2, to = n_spaces, by = 2)
+      for(j in even_chars){
+        stringr::str_sub(x[i], j, j) <- "\u00A0"
+      }
+    }
+  }
+
+
+  x
+}
