@@ -158,7 +158,7 @@ test_that("Page plan with grouped split", {
 
   expect_equal(
     map_chr(auto_split, ~ attr(.x, ".page_note")),
-    c("grp1: A,\ngrp2: a", "grp1: A,\ngrp2: b", "grp1: B,\ngrp2: a", "grp1: B,\ngrp2: b")
+    c("grp1: A, grp2: a", "grp1: A, grp2: b", "grp1: B, grp2: a", "grp1: B, grp2: b")
   )
   expect_equal(
     attr(auto_split, ".page_grp_vars"),
@@ -436,20 +436,59 @@ test_that("Page plan with max_rows", {
   auto_split <- apply_tfrmt(df, mytfrmt)
   man_split <- list(
       tibble::tribble(
-        ~grp, ~ lbl, ~ trt, ~`..tfrmt_row_grp_lbl`,
-        "A" ,  "a" , '22', FALSE,
-        "A" ,  "b" , '11', FALSE,
-        "B" ,  "a" , '24', FALSE
+        ~grp, ~ lbl, ~ trt,
+        "A" ,  "a" , '22',
+        "A" ,  "b" , '11',
+        "B" ,  "a" , '24',
       ),
       tibble::tribble(
-        ~grp, ~ lbl, ~ trt, ~`..tfrmt_row_grp_lbl`,
-        "B" ,  "b" , '55', FALSE,
-        "C" ,  "a" , '12', FALSE,
-        "C" ,  "b" , '19', FALSE
+        ~grp, ~ lbl, ~ trt,
+        "B" ,  "b" , '55',
+        "C" ,  "a" , '12',
+        "C" ,  "b" , '19',
       )
     )
   expect_equal(auto_split, man_split, ignore_attr = TRUE)
 
+
+  # two groups - row_grp_plan label_loc = "column"
+  df <- tibble::tribble(
+    ~ grp1, ~grp2, ~ lbl, ~ prm, ~ trt,
+    "AA"  ,  "A", "a" , "n"  , 22,
+    "AA"  ,  "A", "b" , "n"  , 11,
+    "AA"  ,  "B", "a" , "n"  , 24,
+    "BB"  ,  "B", "b" , "n"  , 55,
+    "BB"  ,  "C", "a" , "n"  , 12,
+    "BB"  ,  "C", "b" , "n"  , 19,
+  ) %>%
+    pivot_longer(trt, names_to = "column", values_to = "value")
+  mytfrmt <- tfrmt(
+    group = c("grp1","grp2"),
+    label = "lbl",
+    param = "prm",
+    column = "column",
+    value = "value",
+    body_plan = body_plan(frmt_structure(group_val=".default", label_val=".default", frmt("xx"))),
+    row_grp_plan = row_grp_plan(label_loc = element_row_grp_loc(location = "column")),
+    page_plan = page_plan(max_rows = 3)
+  )
+  auto_split <- apply_tfrmt(df, mytfrmt)
+  man_split <- list(
+    tibble::tribble(
+      ~grp1, ~grp2, ~ lbl, ~ trt,
+      "AA" ,  "A" ,  "a" , '22',
+      "AA" ,  "A" ,  "b" , '11',
+      "AA" ,  "B" ,  "a" , '24',
+    ),
+    tibble::tribble(
+      ~grp1, ~grp2, ~ lbl, ~ trt,
+      "BB" ,  "B" ,  "b" , '55',
+      "BB" ,  "C" ,  "a" , '12',
+      "BB" ,  "C" ,  "b" , '19',
+    )
+  )
+  expect_equal(auto_split, man_split, ignore_attr = TRUE)
+
 })
 
 test_that("Page plan with max_rows & group-level summary rows",{
@@ -612,7 +651,7 @@ test_that("page plan with both page_structure and max_rows",{
   expect_equal(auto_split, man_split, ignore_attr = TRUE)
 
   expect_equal(
-    map_chr(auto_split, ~ attr(.x, ".page_note")),
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
     c("grp1: cat_1", "grp1: cat_2", "grp1: cat_3", "grp1: cat_3", "grp1: cat_3")
   )
 
@@ -663,7 +702,431 @@ test_that("page plan with page_structure, single level variable",{
   expect_equal(auto_split, man_split, ignore_attr = TRUE)
 
   expect_equal(
-    map_chr(auto_split, ~ attr(.x, ".page_note")),
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
     c("grp1: cat_1")
   )
 })
+
+test_that("page_plan() with transform", {
+  # transform as formula
+  test_data <- tibble::tribble(
+    ~grp1   , ~grp2        , ~my_label      , ~prm  , ~column , ~val ,
+    "cat_1" , "cat_1"      , "cat_1"        , "pct" , "trt"   ,   34 ,
+    "cat_1" , "cat_2"      , "cat_2"        , "pct" , "trt"   ,   43 ,
+    "cat_1" , "sub_cat_2"  , "sub_cat_2"    , "pct" , "trt"   ,   12 ,
+    "cat_1" , "sub_cat_2"  , "sub_cat_3"    , "pct" , "trt"   ,   76 ,
+    "cat_1" , "cat_3"      , "cat_3"        , "pct" , "trt"   ,   56 ,
+    "cat_1" , "sub_cat_3a" , "sub_cat_3a"   , "pct" , "trt"   ,   98 ,
+    "cat_1" , "sub_cat_3b" , "sub_cat_3b_1" , "pct" , "trt"   ,   11 ,
+    "cat_1" , "sub_cat_3b" , "sub_cat_3b_3" , "pct" , "trt"   ,    5
+  )
+
+  tfrmt_plan <- tfrmt(
+    group = c("grp1", "grp2"),
+    label = "my_label",
+    param = "prm",
+    column = "column",
+    value = "val",
+    body_plan = body_plan(
+      frmt_structure(
+        group_val = ".default",
+        label_val = ".default",
+        frmt("xx")
+      )
+    ),
+    row_grp_plan = row_grp_plan(
+      label_loc = element_row_grp_loc(
+        location = "indented"
+      )
+    ),
+    page_plan = page_plan(
+      page_structure(
+        group_val = list(
+          grp1 = ".default"
+        )
+      ),
+      transform = ~ stringr::str_replace(.x, "grp1", "group 1")
+    )
+  )
+
+  auto_split <- apply_tfrmt(test_data, tfrmt_plan)
+
+  expect_equal(
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
+    c("group 1: cat_1")
+  )
+
+  # transform as function
+  tfrmt_plan$page_plan$transform <- function(x) {
+    x |>
+      stringr::str_replace("grp1", "group 1") |>
+      stringr::str_replace("cat_", "category ")
+  }
+
+  auto_split <- apply_tfrmt(test_data, tfrmt_plan)
+
+  expect_equal(
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
+    c("group 1: category 1")
+  )
+})
+
+test_that("page_plan() with transform and multiple 'page by' variables", {
+  test_data <- tibble::tribble(
+    ~grp1   , ~grp2        , ~my_label      , ~prm  , ~column , ~val ,
+    "cat_1" , "cat_1"      , "cat_1"        , "pct" , "trt"   ,   34 ,
+    "cat_1" , "cat_2"      , "cat_2"        , "pct" , "trt"   ,   43 ,
+    "cat_1" , "sub_cat_2"  , "sub_cat_2"    , "pct" , "trt"   ,   12 ,
+    "cat_1" , "sub_cat_2"  , "sub_cat_3"    , "pct" , "trt"   ,   76 ,
+    "cat_1" , "cat_3"      , "cat_3"        , "pct" , "trt"   ,   56 ,
+    "cat_1" , "sub_cat_3a" , "sub_cat_3a"   , "pct" , "trt"   ,   98 ,
+    "cat_1" , "sub_cat_3b" , "sub_cat_3b_1" , "pct" , "trt"   ,   11 ,
+    "cat_1" , "sub_cat_3b" , "sub_cat_3b_3" , "pct" , "trt"   ,    5
+  )
+
+  tfrmt_plan <- tfrmt(
+    group = c("grp1", "grp2"),
+    label = "my_label",
+    param = "prm",
+    column = "column",
+    value = "val",
+    body_plan = body_plan(
+      frmt_structure(
+        group_val = ".default",
+        label_val = ".default",
+        frmt("xx")
+      )
+    ),
+    row_grp_plan = row_grp_plan(
+      label_loc = element_row_grp_loc(
+        location = "indented"
+      )
+    ),
+    page_plan = page_plan(
+      page_structure(
+        group_val = ".default"
+      ),
+      transform = NULL
+    )
+  )
+
+  # without page label transformation
+  auto_split <- apply_tfrmt(test_data, tfrmt_plan)
+
+  expect_equal(
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
+    c(
+      "grp1: cat_1, grp2: cat_1",
+      "grp1: cat_1, grp2: cat_2",
+      "grp1: cat_1, grp2: sub_cat_2",
+      "grp1: cat_1, grp2: cat_3",
+      "grp1: cat_1, grp2: sub_cat_3a",
+      "grp1: cat_1, grp2: sub_cat_3b"
+    )
+  )
+
+  # with page label transformation
+  # we want to go from `grp1: cat_1,\ngrp2: cat_1` to `Group 1 (cat_1),\nGroup 2 (cat_1)`
+  tfrmt_plan$page_plan$transform <- function(x) {
+
+    interim <- x |>
+      stringr::str_replace_all("grp", "Group ") |>
+      stringr::str_replace_all(": ", " (") |>
+      stringr::str_replace_all(",", "),")
+
+    output <- stringr::str_pad(
+      interim,
+      width = nchar(interim)+1,
+      side = "right",
+      pad = ")"
+    )
+
+    output
+  }
+
+  auto_split <- apply_tfrmt(test_data, tfrmt_plan)
+
+  expect_equal(
+    purrr::map_chr(auto_split, ~ attr(.x, ".page_note")),
+    c(
+      "Group 1 (cat_1), Group 2 (cat_1)",
+      "Group 1 (cat_1), Group 2 (cat_2)",
+      "Group 1 (cat_1), Group 2 (sub_cat_2)",
+      "Group 1 (cat_1), Group 2 (cat_3)",
+      "Group 1 (cat_1), Group 2 (sub_cat_3a)",
+      "Group 1 (cat_1), Group 2 (sub_cat_3b)"
+    )
+  )
+})
+
+test_that("apply_page_plan() with label transformation in a complex table", {
+  # include only subjects marked as part of the safety population
+  adsl <- pharmaverseadam::adsl |>
+    dplyr::filter(SAFFL == "Y")
+
+  # Load adverse event data
+  adae <- pharmaverseadam::adae |>
+    dplyr::filter(SAFFL == "Y" & TRTEMFL == "Y")
+
+  # limit printed rows
+  adae <- adae |>
+    dplyr::filter(AESOC %in% unique(AESOC)[1:3]) |>
+    dplyr::group_by(AESOC) |>
+    dplyr::filter(AEDECOD %in% unique(AEDECOD)[1:3]) |>
+    ungroup()
+
+  # Create an ARD that stacks hierarchical data of adverse events
+  # Grouping by treatment, severity, system organ class, and preferred term
+  ard_ae <- cards::ard_stack_hierarchical(
+    data = adae,
+    # by variables must be present in the denominator dataset
+    by = c(TRT01A, AESEV),
+    variables = c(AESOC, AETERM),
+    denominator = adsl,
+    statistic = ~ c("n", "p"),
+    id = USUBJID,
+    over_variables = TRUE,
+    overall = TRUE
+  )
+
+  # create an ARD for where AESEV is "TOTAL"
+  ard_ae2 <- cards::ard_stack_hierarchical(
+    data = adae,
+    # Note: by variables must be present in the denominator dataset
+    by = TRT01A,
+    variables = c(AESOC, AETERM),
+    denominator = adsl,
+    statistic = ~ c("n", "p"),
+    id = USUBJID,
+    over_variables = TRUE,
+    overall = TRUE
+  )
+
+  # Keep required AESEV "TOTAL" rows
+  ard_ae2 <- ard_ae2 |>
+    dplyr::filter(
+      variable != "TRT01A" & group1 != "AESOC" & group1 != "AESEV"
+    )
+
+  ard_ae4 <- ard_ae |>
+    # combine the ards and convert them to the format required for tfrmt
+    cards::bind_ard(ard_ae2) |>
+    # reshape the data
+    shuffle_card(
+      by = c("TRT01A", "AESEV"),
+      fill_overall = "Total",
+      fill_hierarchical_overall = "ANY EVENT"
+    ) |>
+    # transform group-level freqs/pcts into a singular "bigN" row
+    prep_big_n(
+      vars = "TRT01A"
+    ) |>
+    # for nested variables, fill any missing values with "ANY EVENT"
+    prep_hierarchical_fill(
+      vars = c("AESOC", "AETERM"),
+      fill = "ANY EVENT"
+    )
+
+  # create ordering variables, sort by AESOC using the total AESEV variable
+  ordering_aesoc <- ard_ae4 |>
+    dplyr::filter(
+      stat_name == "n",
+      AETERM == "ANY EVENT",
+      TRT01A == "Total",
+      AESEV == "Total"
+    ) |>
+    dplyr::arrange(
+      dplyr::desc(
+        stat
+      )
+    ) |>
+    dplyr::mutate(
+      ord1 = dplyr::row_number()
+    ) |>
+    dplyr::select(
+      AESOC,
+      ord1
+    )
+
+  # Sort by AETERM after AESOC
+  ordering_aeterm <- ard_ae4 |>
+    dplyr::filter(
+      TRT01A == "Total",
+      stat_name == "n",
+      AESEV == "Total"
+    ) |>
+    dplyr::group_by(
+      AESOC
+    ) |>
+    dplyr::arrange(
+      dplyr::desc(
+        stat
+      )
+    ) |>
+    dplyr::mutate(
+      ord2 = dplyr::row_number()
+    ) |>
+    dplyr::select(
+      AESOC,
+      AETERM,
+      ord2
+    )
+
+  # Join on ordering columns
+  ard_ae5 <- ard_ae4 |>
+    dplyr::full_join(
+      ordering_aesoc,
+      by = c("AESOC")
+    ) |>
+    dplyr::full_join(
+      ordering_aeterm,
+      by = c("AESOC", "AETERM")
+    )
+
+  # Extract N values for each treatment where stat_name == "bigN" and use them
+  # to put in names of treatment for formatting output
+  treatment_N <- ard_ae5 |>
+    dplyr::filter(
+      stat_name == "bigN"
+    ) |>
+    dplyr::select(
+      TRT01A,
+      stat
+    ) |>
+    dplyr::rename(
+      stat_N = stat
+    )
+
+  ard_ae6 <- ard_ae5 |>
+    dplyr::filter(stat_name != "bigN") |>
+    dplyr::left_join(treatment_N, by = "TRT01A", suffix = c("", "_N")) |>
+    dplyr::rename(Treatment = TRT01A) |>
+    dplyr::mutate(
+      Treatment = dplyr::case_when(
+        Treatment == "Xanomeline Low Dose" ~ paste0(
+          "Xanomeline Low Dose (N=",
+          stat_N,
+          ")"
+        ),
+        Treatment == "Xanomeline High Dose" ~ paste0(
+          "Xanomeline High Dose (N=",
+          stat_N,
+          ")"
+        ),
+        Treatment == "Placebo" ~ paste0("Placebo (N=", stat_N, ")"),
+        TRUE ~ Treatment
+      )
+    ) |>
+    # Remove extra stat column
+    dplyr::select(
+      -stat_N
+    ) |>
+    # remove total treatment column
+    dplyr::filter(
+      Treatment != "Total"
+    ) |>
+    dplyr::select(
+      Treatment,
+      AESOC,
+      AETERM,
+      stat,
+      stat_name,
+      AESEV,
+      ord1,
+      ord2
+    )
+
+  # test with transform as formula
+  test_tfrmt <- tfrmt_n_pct(
+    n = "n",
+    pct = "p",
+    pct_frmt_when = frmt_when(
+      "==1" ~ frmt("(100%)"),
+      ">=0.995" ~ frmt("(>99%)"),
+      "==0" ~ frmt(""),
+      "<=0.01" ~ frmt("(<1%)"),
+      "TRUE" ~ frmt("(xx.x%)", transform = ~ . * 100)
+    )
+  ) |>
+    tfrmt(
+      group = c(Treatment, AESOC),
+      label = AETERM,
+      param = stat_name,
+      value = stat,
+      column = AESEV,
+      sorting_cols = c(Treatment, ord1, ord2),
+      col_plan = col_plan(
+        "System Organ Class
+        Preferred Term" = AESOC,
+        -Treatment,
+        -ord1,
+        -ord2
+      ),
+      page_plan = page_plan(
+        page_structure(
+          group_val = list(
+            Treatment = ".default"
+          )
+        ),
+        note_loc = "subtitle",
+        transform = ~ stringr::str_replace(.x, "Treatment", "Group")
+      ),
+      row_grp_plan = row_grp_plan(
+        row_grp_structure(
+          group_val = ".default",
+          element_block(post_space = " ")
+        )
+      )
+    )
+
+  auto_split <- apply_tfrmt(ard_ae6, test_tfrmt)
+
+  expect_identical(
+    purrr::map_chr(
+      auto_split,
+      ~ attr(.x, ".page_note")
+    ),
+    c(
+      "Group: Placebo (N=86)",
+      "Group: Xanomeline High Dose (N=72)",
+      "Group: Xanomeline Low Dose (N=96)"
+    )
+  )
+
+  # test with transform as function
+  test_tfrmt$page_plan$transform <- function(x) {
+    stringr::str_replace(x, "Treatment", "Group")
+  }
+
+  auto_split <- apply_tfrmt(ard_ae6, test_tfrmt)
+
+    expect_identical(
+    purrr::map_chr(
+      auto_split,
+      ~ attr(.x, ".page_note")
+    ),
+    c(
+      "Group: Placebo (N=86)",
+      "Group: Xanomeline High Dose (N=72)",
+      "Group: Xanomeline Low Dose (N=96)"
+    )
+  )
+
+  # test with transform NULL -> we get the original behaviour (page labels using
+  # the variable name - Treatment)
+  test_tfrmt$page_plan$transform <- NULL
+
+  auto_split <- apply_tfrmt(ard_ae6, test_tfrmt)
+
+  expect_identical(
+    purrr::map_chr(
+      auto_split,
+      ~ attr(.x, ".page_note")
+    ),
+    c(
+      "Treatment: Placebo (N=86)",
+      "Treatment: Xanomeline High Dose (N=72)",
+      "Treatment: Xanomeline Low Dose (N=96)"
+    )
+  )
+})
