@@ -1,4 +1,3 @@
-
 test_that("Defining the spanning structure", {
 
   s1 <- span_structure(
@@ -226,7 +225,10 @@ test_that("Test applying a col_plan - tidyselect",{
   )
 
   cp_drop <- col_plan(
-    span_structure(col1 = starts_with("test"), col2 = c(val2,everything())),
+    span_structure(
+      col1 = starts_with("test"),
+      col2 = c(val2, everything())
+    ),
     everything(),
     first_col,
     .drop = TRUE
@@ -782,7 +784,9 @@ test_that("Order is kept for multi-col columns",{
     names()
 
   new_name_ord_in_dat <- test %>%
-    select(starts_with("col")) %>%
+    select(
+      tidyselect::starts_with("col")
+    ) %>%
     unite("new", sep=.tlang_delim) %>%
     pull(new)
 
@@ -1461,7 +1465,10 @@ test_that("Build simple tfrmt with stub header",{
   )
 
   suppressMessages({
-    processed_gt <- print_to_gt(tfrmt = basic_multi_column_template, .data = basic_example_dataset)
+    processed_gt <- print_to_gt(
+      tfrmt = basic_multi_column_template,
+      .data = basic_example_dataset
+    )
   })
 
   expect_equal(
@@ -1471,7 +1478,7 @@ test_that("Build simple tfrmt with stub header",{
   )
   expect_equal(
     processed_gt[["_stubhead"]]$label,
-    "grp"
+    c("grp")
   )
 
 
@@ -1521,8 +1528,62 @@ test_that("Build simple tfrmt with stub header",{
   )
   expect_equal(
     processed_gt[["_stubhead"]]$label,
-    NULL
+    ""
   )
 
 
+  # multi group stub header
+  basic_multi_column_template <- tfrmt(
+    group = c(grp1, grp2),
+    label = quo(label),
+    param = parm,
+    value = val,
+    column = c(test1,test2),
+    col_plan = col_plan(
+      `Group 1` = grp1,
+      `Group 2` = grp2,
+      `Row label` =label,
+      tst = col4,
+      col3,
+      col1,
+      -col5,
+      -col2
+    ),
+    row_grp_plan = row_grp_plan(
+      label_loc = element_row_grp_loc(location = "column"))
+  )
+
+  basic_example_dataset <- tibble::tribble(
+    ~grp1, ~grp2,     ~label,    ~test1, ~test2,    ~parm, ~val,
+    "G1", "g1", "rowlabel1",  "span 1", "col1",  "value",    1,
+    "G1", "g1", "rowlabel1",  "span 1", "col2",  "value",    1,
+    "G1", "g1", "rowlabel1",        NA, "col3",  "value",    1,
+    "G1", "g1", "rowlabel1",        NA, "col4",  "value",    1,
+    "G1", "g1", "rowlabel1",        NA, "col5",  "value",    1,
+    "G1", "g1", "rowlabel2",  "span 1", "col1",  "value",    2,
+    "G1", "g1", "rowlabel2",  "span 1", "col2",  "value",    2,
+    "G1", "g1", "rowlabel2",        NA, "col3",  "value",    2,
+    "G1", "g1", "rowlabel2",        NA, "col4",  "value",    2,
+    "G1", "g1", "rowlabel2",        NA, "col5",  "value",    2,
+    "G1", "g2", "rowlabel3",  "span 1", "col1",  "value",    3,
+    "G1", "g2", "rowlabel3",  "span 1", "col2",  "value",    3,
+    "G1", "g2", "rowlabel3",        NA, "col3",  "value",    3,
+    "G1", "g2", "rowlabel3",        NA, "col4",  "value",    3,
+    "G1", "g2", "rowlabel3",        NA, "col5",  "value",    3,
+  )
+
+  suppressMessages({
+    processed_gt <- print_to_gt(tfrmt = basic_multi_column_template, .data = basic_example_dataset)
+  })
+
+  expect_equal(
+    processed_gt[["_boxhead"]]$column_label %>% map_chr(as.character),
+    c("grp1", "grp2", "label", "tst", "col3", "col1", "..tfrmt_row_grp_lbl"
+    )
+  )
+  expect_equal(
+    processed_gt[["_stubhead"]]$label,
+    c("Group 1", "Group 2", "Row label")
+  )
+
 })
