@@ -54,7 +54,10 @@ plan  <- tfrmt(
     frmt_structure(group_val = "B", label_val = "j", frmt("xx.xx"))
   ),
   # These are the variables to keep
-  col_plan= col_plan(everything(), -starts_with("ord")),
+  col_plan = col_plan(
+    everything(),
+    -starts_with("ord")
+  ),
   row_grp_plan = row_grp_plan(label_loc = element_row_grp_loc("spanning"))
 )
 
@@ -152,7 +155,10 @@ test_that("Check apply_tfrmt for mock data",{
     ),
     row_grp_plan = row_grp_plan(label_loc = element_row_grp_loc("spanning")),
     # These are the variables to keep
-    col_plan = col_plan(everything(), -starts_with("ord"))
+    col_plan = col_plan(
+      everything(),
+      -starts_with("ord")
+    )
   )
 
 
@@ -211,7 +217,7 @@ test_that("Check apply_tfrmt for mock data",{
   expect_equal(
     mock_dat,
     expected_dat,
-    ignore_attr = c("class",".col_plan_vars",".footnote_locs")
+    ignore_attr = c("class",".col_plan_vars",".footnote_locs", ".stub_header")
   )
 
   # duplicate params for a single group/label combo
@@ -255,7 +261,7 @@ test_that("Check apply_tfrmt for mock data",{
                  "grp1_2", "my_label_2", "xxx" ,  "xxx"  ,
                  "grp1_2", "my_label_2", "xx.x",  "xx.x" ,
                ),
-               ignore_attr = c("class",".col_plan_vars",".footnote_locs"))
+               ignore_attr = c("class",".col_plan_vars",".footnote_locs", ".stub_header"))
 
 })
 
@@ -286,7 +292,7 @@ test_that("Test body_plan missing", {
                  select(-param) %>%
                  mutate(val = as.character(val)) %>%
                  pivot_wider(names_from = column, values_from = val),
-               ignore_attr = c("class",".col_plan_vars",".footnote_locs"))
+               ignore_attr = c("class",".col_plan_vars",".footnote_locs", ".stub_header"))
 })
 
 
@@ -326,17 +332,15 @@ test_that("incomplete body_plan where params share label",{
       )
 
   man_tfrmt <- tibble::tribble(
-    ~rowlbl1,  ~rowlbl2,    ~ A   ,       ~..tfrmt_row_grp_lbl,
-    "topgrp", "lowergrp1", NA_character_, TRUE,
-    "topgrp", "  n pct"  ,c("1","50"),   FALSE,
-    "topgrp", "  mean"   , " 2.0",        FALSE,
-    "topgrp", "lowergrp2", NA_character_, TRUE,
-    "topgrp", "  n pct"  , c("2","40"),   FALSE,
-    "topgrp", "  mean"   , " 5.0",        FALSE
-  ) %>% group_by(rowlbl1)
+    ~rowlbl1, ~grp,  ~rowlbl2,    ~ A   ,
+    "topgrp", "lowergrp1", "n pct"  , c("1","50"),
+    "topgrp", "lowergrp1", "mean"   , " 2.0",
+    "topgrp", "lowergrp2", "n pct"  , c("2","40"),
+    "topgrp", "lowergrp2", "mean"   , " 5.0"
+  )
 
   expect_equal(auto_tfrmt, man_tfrmt,
-               ignore_attr = c("class",".col_plan_vars",".footnote_locs"))
+               ignore_attr = c("class",".col_plan_vars",".footnote_locs", ".stub_header"))
 })
 
 
@@ -441,7 +445,7 @@ test_that("struct utils quote escaping",{
   expect_equal(
     auto_tfrmt <- apply_tfrmt(dd, tfrmt_spec) |> dplyr::select(rowlbl2:A),
     man_tfrmt,
-    ignore_attr = c("class",".col_plan_vars",".footnote_locs")
+    ignore_attr = c("class",".col_plan_vars",".footnote_locs", ".stub_header")
   )
 
 })
